==> ipyfilite-0.1.10.tar.gz: ipyfilite-0.1.10/ipyfilite/download/fs.js <==
Object.create({
    mount: function(mount /* ignored */) {
        const node = this._pyodide.FS.createNode(
            null, "/", 0o40000 /* S_IFDIR */ | 0o777 /* a=rwx */,
        );
        node.node_ops = this.node_ops;
        node.stream_ops = this.stream_ops;
        node.size = 4096;
        node.timestamp = Date.now();
        node._downloads = {};
        node._pre_downloads = {};
        node._pyodide = this._pyodide;
        node._channel = this._channel;
        node._session = this._session;
        return node;
    },
    create_download: function(parent, uuid, filename) {
        parent._pre_downloads[uuid] = { filename };
        return `${parent.mount.mountpoint}/${uuid}`;
    },
    close_download: function(parent, uuid) {
        if (parent._pre_downloads[uuid] !== undefined) {
            delete parent._pre_downloads[uuid];
            return;
        }
        const node = parent._downloads[uuid];
        if (node._opened !== false) {
            throw new parent._pyodide.FS.ErrnoError(
                parent._pyodide.ERRNO_CODES.EEXIST
            );
        }
        this._channel.postMessage({
            kind: "download-close",
            session: this._session,
            uuid,
        });
        parent._pyodide.FS.destroyNode(node);
        delete parent._downloads[uuid];
    },
    node_ops: {
        getattr: function(node) {
            return {
                dev: 1,
                ino: node.id,
                mode: node.mode,
                nlink: 1,
                uid: 0,
                gid: 0,
                rdev: undefined,
                size: node.size,
                atime: new Date(node.timestamp),
                mtime: new Date(node.timestamp),
                ctime: new Date(node.timestamp),
                blksize: 4096,
                blocks: Math.ceil(node.size / 4096),
            };
        },
        setattr: function(node, attr) {
            if (attr.timestamp !== undefined) {
                node.timestamp = attr.timestamp;
            }
            if (attr.size !== undefined) {
                if (node.size !== attr.size) {
                    throw new node._pyodide.FS.ErrnoError(
                        node._pyodide.ERRNO_CODES.ESPIPE
                    );
                }
            }
            if (attr.mode !== undefined) {
                throw new node._pyodide.FS.ErrnoError(
                    node._pyodide.ERRNO_CODES.EPERM
                );
            }
        },
        readdir: function(node) {
            if (!(node.mode & 16384 /* S_IFDIR */)) {
                throw new node._pyodide.FS.ErrnoError(
                    node._pyodide.ERRNO_CODES.ENOTDIR
                );
            }
            const entries = ['.', '..'];
            for (const key in node._downloads) {
                if (!node._downloads.hasOwnProperty(key)) {
                    continue;
                }
                entries.push(key);
            }
            return entries;
        },
        lookup: function(parent, name /* ignored */) {
            throw new parent._pyodide.FS.ErrnoError(
                parent._pyodide.ERRNO_CODES.ENOENT
            );
        },
        mknod: (parent, name, mode, dev /* ignored */) => {
            if (!parent._pyodide.FS.isFile(mode)) {
                throw new parent._pyodide.FS.ErrnoError(
                    parent._pyodide.ERRNO_CODES.EINVAL
                );
            }
            const uuid = name;
            if (parent._pre_downloads[uuid] === undefined) {
                throw new parent._pyodide.FS.ErrnoError(
                    parent._pyodide.ERRNO_CODES.EPERM
                );
            }
            const { filename } = parent._pre_downloads[uuid];
            const node = parent._pyodide.FS.createNode(
                parent, uuid, 0o100000 /* S_IFREG */ | 0o222 /* a=w */,
            );
            node.filename = filename;
            node.node_ops = parent.node_ops;
            node.stream_ops = parent.stream_ops;
            node.size = 0;
            node.timestamp = Date.now();
            node.parent.timestamp = node.timestamp;
            node._opened = false;
            node._pyodide = parent._pyodide;
            node._channel = parent._channel;
            node._session = parent._session;
            parent._downloads[uuid] = node;
            delete parent._pre_downloads[uuid];
            node._channel.postMessage({
                kind: "download-open",
                session: node._session,
                uuid,
                name: filename,
            });
            return node;
        },
    },
    stream_ops: {
        open: function(stream) {
            if (stream.node._pyodide.FS.isDir(stream.node.mode)) {
                return;
            }
            if (stream.node._opened !== false) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.EEXIST
                );
            }
            stream.node._opened = true;
        },
        write: function(
            stream, buffer, offset, length, position /* ignored */,
        ) {
            if (stream.node._opened !== true) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.ENODEV
                )
            };
            stream.node.size += length;
            stream.node.timestamp = Date.now();
            stream.node._channel.postMessage({
                kind: "download-chunk",
                session: stream.node._session,
                uuid: stream.node.name,
                chunk: buffer.slice(offset, offset+length),
            });
            return length;
        },
        close: function(stream) {
            if (stream.node._pyodide.FS.isDir(stream.node.mode)) {
                return;
            }
            if (stream.node._opened !== true) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.ENODEV
                )
            };
            stream.node._opened = false;
        },
        llseek: function(stream, offset, whence) {
            let position = offset;
            if (whence === 1) {
                position += stream.position;
            } else if (whence === 2) {
                if (stream.node._pyodide.FS.isFile(stream.node.mode)) {
                    position += stream.node.size;
                }
            }
            if (position < 0) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.EINVAL
                );
            }
            if (
                !stream.node._pyodide.FS.isDir(stream.node.mode) &&
                (position !== stream.node.size)
            ) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.ESPIPE
                );
            }
            return position;
        },
    },
})

==> ipyfilite-0.1.11.tar.gz: ipyfilite-0.1.11/ipyfilite/download/fs.js <==
Object.create({
    mount: function(mount /* ignored */) {
        const node = this._pyodide.FS.createNode(
            null, "/", 0o40000 /* S_IFDIR */ | 0o777 /* a=rwx */,
        );
        node.node_ops = this.node_ops;
        node.stream_ops = this.stream_ops;
        node.size = 4096;
        node.timestamp = Date.now();
        node._downloads = {};
        node._pre_downloads = {};
        node._pyodide = this._pyodide;
        node._channel = this._channel;
        return node;
    },
    create_download: function(parent, uuid, filename) {
        parent._pre_downloads[uuid] = { filename };
        return `${parent.mount.mountpoint}/${uuid}`;
    },
    close_download: function(parent, uuid) {
        if (parent._pre_downloads[uuid] !== undefined) {
            delete parent._pre_downloads[uuid];
            return;
        }
        const node = parent._downloads[uuid];
        if (node._opened !== false) {
            throw new parent._pyodide.FS.ErrnoError(
                parent._pyodide.ERRNO_CODES.EEXIST
            );
        }
        this._writer.close();
        parent._pyodide.FS.destroyNode(node);
        delete parent._downloads[uuid];
    },
    node_ops: {
        getattr: function(node) {
            return {
                dev: 1,
                ino: node.id,
                mode: node.mode,
                nlink: 1,
                uid: 0,
                gid: 0,
                rdev: undefined,
                size: node.size,
                atime: new Date(node.timestamp),
                mtime: new Date(node.timestamp),
                ctime: new Date(node.timestamp),
                blksize: 4096,
                blocks: Math.ceil(node.size / 4096),
            };
        },
        setattr: function(node, attr) {
            if (attr.timestamp !== undefined) {
                node.timestamp = attr.timestamp;
            }
            if (attr.size !== undefined) {
                if (node.size !== attr.size) {
                    throw new node._pyodide.FS.ErrnoError(
                        node._pyodide.ERRNO_CODES.ESPIPE
                    );
                }
            }
            if (attr.mode !== undefined) {
                throw new node._pyodide.FS.ErrnoError(
                    node._pyodide.ERRNO_CODES.EPERM
                );
            }
        },
        readdir: function(node) {
            if (!(node.mode & 16384 /* S_IFDIR */)) {
                throw new node._pyodide.FS.ErrnoError(
                    node._pyodide.ERRNO_CODES.ENOTDIR
                );
            }
            const entries = ['.', '..'];
            for (const key in node._downloads) {
                if (!node._downloads.hasOwnProperty(key)) {
                    continue;
                }
                entries.push(key);
            }
            return entries;
        },
        lookup: function(parent, name /* ignored */) {
            throw new parent._pyodide.FS.ErrnoError(
                parent._pyodide.ERRNO_CODES.ENOENT
            );
        },
        mknod: (parent, name, mode, dev /* ignored */) => {
            if (!parent._pyodide.FS.isFile(mode)) {
                throw new parent._pyodide.FS.ErrnoError(
                    parent._pyodide.ERRNO_CODES.EINVAL
                );
            }
            const uuid = name;
            if (parent._pre_downloads[uuid] === undefined) {
                throw new parent._pyodide.FS.ErrnoError(
                    parent._pyodide.ERRNO_CODES.EPERM
                );
            }
            const { filename } = parent._pre_downloads[uuid];
            const node = parent._pyodide.FS.createNode(
                parent, uuid, 0o100000 /* S_IFREG */ | 0o222 /* a=w */,
            );
            node.filename = filename;
            node.node_ops = parent.node_ops;
            node.stream_ops = parent.stream_ops;
            node.size = 0;
            node.timestamp = Date.now();
            node.parent.timestamp = node.timestamp;
            node._opened = false;
            node._pyodide = parent._pyodide;
            const transform = new TransformStream();
            node._writer = transform.writable.getWriter();
            parent._downloads[uuid] = node;
            delete parent._pre_downloads[uuid];
            parent._channel.postMessage({
                kind: "download",
                name: filename,
                stream: transform.readable,
            }, [transform.readable]);
            return node;
        },
    },
    stream_ops: {
        open: function(stream) {
            if (stream.node._pyodide.FS.isDir(stream.node.mode)) {
                return;
            }
            if (stream.node._opened !== false) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.EEXIST
                );
            }
            stream.node._opened = true;
        },
        write: function(
            stream, buffer, offset, length, position /* ignored */,
        ) {
            if (stream.node._opened !== true) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.ENODEV
                )
            };
            stream.node.size += length;
            stream.node.timestamp = Date.now();
            stream.node._writer.write(buffer.slice(offset, offset+length));
            return length;
        },
        close: function(stream) {
            if (stream.node._pyodide.FS.isDir(stream.node.mode)) {
                return;
            }
            if (stream.node._opened !== true) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.ENODEV
                )
            };
            stream.node._opened = false;
        },
        llseek: function(stream, offset, whence) {
            let position = offset;
            if (whence === 1) {
                position += stream.position;
            } else if (whence === 2) {
                if (stream.node._pyodide.FS.isFile(stream.node.mode)) {
                    position += stream.node.size;
                }
            }
            if (position < 0) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.EINVAL
                );
            }
            if (
                !stream.node._pyodide.FS.isDir(stream.node.mode) &&
                (position !== stream.node.size)
            ) {
                throw new stream.node._pyodide.FS.ErrnoError(
                    stream.node._pyodide.ERRNO_CODES.ESPIPE
                );
            }
            return position;
        },
    },
})
